@@ -1,7 +1,7 @@
 /*
- * $Id: CoreMessages.java 14674 2009-05-09 08:55:53Z rossmason $
+ * $Id: CoreMessages.java 21903 2011-05-13 19:40:30Z tcarlson $
  * --------------------------------------------------------------------------------------
- * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
+ * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
@@ -10,24 +10,29 @@
 
 package org.mule.config.i18n;
 
-import org.mule.AbstractExceptionListener;
+import org.mule.MessageExchangePattern;
 import org.mule.api.config.ConfigurationBuilder;
 import org.mule.api.endpoint.EndpointURI;
 import org.mule.api.endpoint.ImmutableEndpoint;
-import org.mule.api.model.EntryPointResolver;
+import org.mule.api.endpoint.InboundEndpoint;
+import org.mule.api.processor.MessageProcessor;
+import org.mule.api.registry.ServiceType;
 import org.mule.api.retry.RetryPolicyTemplate;
-import org.mule.api.routing.InboundRouterCollection;
 import org.mule.api.routing.OutboundRouter;
-import org.mule.api.routing.ResponseRouterCollection;
 import org.mule.api.service.Service;
 import org.mule.api.transaction.Transaction;
+import org.mule.api.transaction.TransactionConfig;
+import org.mule.api.transformer.DataType;
 import org.mule.api.transformer.Transformer;
 import org.mule.config.MuleManifest;
+import org.mule.context.notification.ListenerSubscriptionPair;
+import org.mule.exception.AbstractExceptionStrategy;
 import org.mule.util.ClassUtils;
 import org.mule.util.DateUtils;
 import org.mule.util.StringMessageUtils;
 import org.mule.util.StringUtils;
 
+import java.lang.reflect.Method;
 import java.util.Date;
 import java.util.List;
 
@@ -99,7 +104,7 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 12);
     }
 
-    public static Message messageIsOfType(Class type)
+    public static Message messageIsOfType(Class<?> type)
     {
         return factory.createMessage(BUNDLE_PATH, 18, ClassUtils.getSimpleName(type));
     }
@@ -124,14 +129,14 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 23);
     }
 
-    public static Message failedToRouterViaEndpoint(ImmutableEndpoint endpoint)
+    public static Message failedToRouterViaEndpoint(MessageProcessor target)
     {
-        return factory.createMessage(BUNDLE_PATH, 30, endpoint);
+        return factory.createMessage(BUNDLE_PATH, 30, target);
     }
 
-    public static Message cannotUseDisposedConnector()
+    public static Message lifecycleErrorCannotUseConnector(String name, String lifecyclePhase)
     {
-        return factory.createMessage(BUNDLE_PATH, 32);
+        return factory.createMessage(BUNDLE_PATH, 32, name, lifecyclePhase);
     }
 
     public static Message connectorCausedError()
@@ -219,20 +224,26 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 52);
     }
 
-    public static Message transformUnexpectedType(Class class1, Class returnClass)
+    public static Message transformUnexpectedType(Class<?> class1, Class<?> returnClass)
     {
-        return factory.createMessage(BUNDLE_PATH, 53, ClassUtils.getSimpleName(class1), ClassUtils.getSimpleName(returnClass));
+        return factory.createMessage(BUNDLE_PATH, 53, ClassUtils.getSimpleName(class1),
+            ClassUtils.getSimpleName(returnClass));
+    }
+
+    public static Message transformUnexpectedType(DataType<?> dt1, DataType<?> dt2)
+    {
+        return factory.createMessage(BUNDLE_PATH, 53, dt1, dt2);
     }
 
     public static Message transformOnObjectUnsupportedTypeOfEndpoint(String name,
-                                                                     Class class1,
+                                                                     Class<?> class1,
                                                                      ImmutableEndpoint endpoint)
     {
         return factory.createMessage(BUNDLE_PATH, 54, name, StringMessageUtils.toString(class1),
-                (endpoint != null ? endpoint.getEndpointURI() : null));
+            (endpoint != null ? endpoint.getEndpointURI() : null));
     }
 
-    public static Message transformFailedFrom(Class clazz)
+    public static Message transformFailedFrom(Class<?> clazz)
     {
         return factory.createMessage(BUNDLE_PATH, 55, clazz);
     }
@@ -252,20 +263,26 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 58, string);
     }
 
-    public static Message messageNotSupportedByAdapter(String string, String string2)
+    public static Message messageNotSupportedByMuleMessageFactory(Object message, Class<?> creator)
     {
-        return factory.createMessage(BUNDLE_PATH, 59, string, string2);
+        String messageClass = (message != null ? message.getClass().getName() : "null");
+        String creatorClass = (creator != null ? creator.getName() : "null class");
+        
+        return factory.createMessage(BUNDLE_PATH, 59, messageClass, creatorClass);
     }
 
     public static Message tooManyAcceptableMethodsOnObjectForTypes(Object object, Object types)
     {
-        return factory.createMessage(BUNDLE_PATH, 60, StringMessageUtils.toString(object), StringMessageUtils.toString(types));
+        return factory.createMessage(BUNDLE_PATH, 60, StringMessageUtils.toString(object),
+            StringMessageUtils.toString(types));
     }
 
-    public static Message cannotSetPropertyOnObjectWithParamType(String property, Class class1, Class class2)
+    public static Message cannotSetPropertyOnObjectWithParamType(String property,
+                                                                 Class<?> class1,
+                                                                 Class<?> class2)
     {
         return factory.createMessage(BUNDLE_PATH, 61, property, StringMessageUtils.toString(class1),
-                StringMessageUtils.toString(class2));
+            StringMessageUtils.toString(class2));
     }
 
     public static Message noComponentForEndpoint()
@@ -328,7 +345,7 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 75, object, service);
     }
 
-    public static Message objectNotFound(String object)
+    public static Message objectNotFound(Object object)
     {
         return factory.createMessage(BUNDLE_PATH, 76, object);
     }
@@ -478,30 +495,36 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 108);
     }
 
-    public static Message methodWithParamsNotFoundOnObject(String method, Object class1, Class class2)
+    public static Message methodWithParamsNotFoundOnObject(String method, Object class1, Class<?> class2)
     {
         return factory.createMessage(BUNDLE_PATH, 109, method, StringMessageUtils.toString(class1),
-                StringMessageUtils.toString(class2));
+            StringMessageUtils.toString(class2));
     }
 
     public static Message transformFailed(String from, String to)
     {
         return factory.createMessage(BUNDLE_PATH, 110, from, to);
     }
-
+    
+    public static Message transformFailed(String from, DataType<?> to)
+    {
+        return transformFailed(from, to.getClass().getName());
+    }
+    
     public static Message cryptoFailure()
     {
         return factory.createMessage(BUNDLE_PATH, 112);
     }
 
-    public static Message schemeNotCompatibleWithConnector(String scheme, Class expectedClass)
+    public static Message schemeNotCompatibleWithConnector(String scheme, Class<?> expectedClass)
     {
         return factory.createMessage(BUNDLE_PATH, 115, scheme, expectedClass);
     }
 
     public static Message noEntryPointFoundWithArgs(Object object, Object args)
     {
-        return factory.createMessage(BUNDLE_PATH, 116, StringMessageUtils.toString(object), StringMessageUtils.toString(args));
+        return factory.createMessage(BUNDLE_PATH, 116, StringMessageUtils.toString(object),
+            StringMessageUtils.toString(args));
     }
 
     public static Message authNoSecurityProvider(String providerName)
@@ -619,16 +642,16 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 156, scheme);
     }
 
-    public static Message propertyIsNotSupportedType(String property, Class expected, Class actual)
+    public static Message propertyIsNotSupportedType(String property, Class<?> expected, Class<?> actual)
     {
         return factory.createMessage(BUNDLE_PATH, 157, property, StringMessageUtils.toString(expected),
-                StringMessageUtils.toString(actual));
+            StringMessageUtils.toString(actual));
     }
 
-    public static Message propertyIsNotSupportedType(String property, Class[] expected, Class actual)
+    public static Message propertyIsNotSupportedType(String property, Class<?>[] expected, Class<?> actual)
     {
         return factory.createMessage(BUNDLE_PATH, 157, property, StringMessageUtils.toString(expected),
-                StringMessageUtils.toString(actual));
+            StringMessageUtils.toString(actual));
     }
 
     public static Message containerAlreadyRegistered(String name)
@@ -651,7 +674,7 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 163);
     }
 
-    public static Message reconnectStrategyFailed(Class strategy, String description)
+    public static Message reconnectStrategyFailed(Class<?> strategy, String description)
     {
         return factory.createMessage(BUNDLE_PATH, 164, StringMessageUtils.toString(strategy), description);
     }
@@ -666,7 +689,7 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 166, string);
     }
 
-    public static Message componentIsStopped(String name)
+    public static Message isStopped(String name)
     {
         return factory.createMessage(BUNDLE_PATH, 167, name);
     }
@@ -696,9 +719,10 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 175, header, value);
     }
 
-    public static Message transformOnObjectNotOfSpecifiedType(String name, Object expectedType)
+    public static Message transformOnObjectNotOfSpecifiedType(DataType<?> resultType, Object expectedType)
     {
-        return factory.createMessage(BUNDLE_PATH, 177, name, expectedType);
+        return factory.createMessage(BUNDLE_PATH, 177, resultType.getType().getName(),
+            expectedType.getClass());
     }
 
     public static Message cannotUseTxAndRemoteSync()
@@ -716,16 +740,16 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 183, string);
     }
 
-    public static Message objectNotOfCorrectType(Class actualClass, Class[] expectedClass)
+    public static Message objectNotOfCorrectType(Class<?> actualClass, Class<?>[] expectedClass)
     {
         return factory.createMessage(BUNDLE_PATH, 185, StringMessageUtils.toString(actualClass),
-                StringMessageUtils.toString(expectedClass));
+            StringMessageUtils.toString(expectedClass));
     }
 
-    public static Message objectNotOfCorrectType(Class actualClass, Class expectedClass)
+    public static Message objectNotOfCorrectType(Class<?> actualClass, Class<?> expectedClass)
     {
         return factory.createMessage(BUNDLE_PATH, 185, StringMessageUtils.toString(actualClass),
-                StringMessageUtils.toString(expectedClass));
+            StringMessageUtils.toString(expectedClass));
     }
 
     public static Message failedToConvertStringUsingEncoding(String encoding)
@@ -826,10 +850,10 @@ public class CoreMessages extends MessageFactory
     public static Message tooManyMatchingMethodsOnObjectWhichReturn(Object object, Object returnType)
     {
         return factory.createMessage(BUNDLE_PATH, 216, StringMessageUtils.toString(object),
-                StringMessageUtils.toString(returnType));
+            StringMessageUtils.toString(returnType));
     }
 
-    public static Message failedToSetProxyOnService(Object proxy, Class routerClass)
+    public static Message failedToSetProxyOnService(Object proxy, Class<?> routerClass)
     {
         return factory.createMessage(BUNDLE_PATH, 217, proxy, routerClass);
     }
@@ -844,10 +868,10 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 219, name);
     }
 
-    public static Message noMatchingMethodsOnObjectReturning(Object object, Class returnType)
+    public static Message noMatchingMethodsOnObjectReturning(Object object, Class<?> returnType)
     {
         return factory.createMessage(BUNDLE_PATH, 220, StringMessageUtils.toString(object),
-                StringMessageUtils.toString(returnType));
+            StringMessageUtils.toString(returnType));
     }
 
     public static Message moreThanOneConnectorWithProtocol(String protocol, String connectors)
@@ -885,7 +909,7 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 228, phaseName, object);
     }
 
-    public static Message unrecognisedServiceType(String type)
+    public static Message unrecognisedServiceType(ServiceType type)
     {
         return factory.createMessage(BUNDLE_PATH, 229, type);
     }
@@ -895,24 +919,13 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 230, name);
     }
 
-    public static Message inboundRouterMustUseInboundEndpoints(InboundRouterCollection router,
-                                                               ImmutableEndpoint endpoint)
-    {
-        return factory.createMessage(BUNDLE_PATH, 232, endpoint, router);
-    }
-
-    public static Message outboundRouterMustUseOutboudEndpoints(OutboundRouter router, ImmutableEndpoint endpoint)
+    public static Message outboundRouterMustUseOutboudEndpoints(OutboundRouter router,
+                                                                ImmutableEndpoint endpoint)
     {
         return factory.createMessage(BUNDLE_PATH, 233, endpoint, router);
     }
 
-    public static Message responseRouterMustUseInboundEndpoints(ResponseRouterCollection router,
-                                                                ImmutableEndpoint endpoint)
-    {
-        return factory.createMessage(BUNDLE_PATH, 234, endpoint, router);
-    }
-
-    public static Message exceptionListenerMustUseOutboundEndpoint(AbstractExceptionListener exceptionListener,
+    public static Message exceptionListenerMustUseOutboundEndpoint(AbstractExceptionStrategy exceptionListener,
                                                                    ImmutableEndpoint endpoint)
     {
         return factory.createMessage(BUNDLE_PATH, 235, endpoint, exceptionListener);
@@ -920,24 +933,24 @@ public class CoreMessages extends MessageFactory
 
     /**
      * Returns a message that is a product informatin.
-     *
+     * 
      * @return message
      */
     public static Message productInformation()
     {
         String notset = CoreMessages.notSet().getMessage();
-        return factory.createMessage(BUNDLE_PATH, 236, StringUtils.defaultString(MuleManifest.getProductDescription(), notset),
-                StringUtils.defaultString(MuleManifest.getProductVersion(), notset), StringUtils.defaultString(
-                MuleManifest.getVendorName(), notset)
-                + " "
-                + StringUtils.defaultString(
-                MuleManifest.getVendorUrl(),
-                notset));
+        return factory.createMessage(BUNDLE_PATH, 236, StringUtils.defaultString(
+            MuleManifest.getProductDescription(), notset), StringUtils.defaultString(
+            MuleManifest.getProductVersion(), notset), StringUtils.defaultString(
+            MuleManifest.getVendorName(), notset)
+                                                       + " "
+                                                       + StringUtils.defaultString(
+                                                           MuleManifest.getVendorUrl(), notset));
     }
 
-    public static Message noTransformerFoundForMessage(Class input, Class output)
+    public static Message noTransformerFoundForMessage(DataType<?> input, DataType<?> output)
     {
-        return factory.createMessage(BUNDLE_PATH, 237, input.getName(), output.getName());
+        return factory.createMessage(BUNDLE_PATH, 237, input, output);
     }
 
     public static Message errorReadingStream()
@@ -946,43 +959,41 @@ public class CoreMessages extends MessageFactory
     }
 
     public static Message noEntryPointFoundForNoArgsMethodUsingResolver(final Object component,
-                                                                        final String methodName,
-                                                                        EntryPointResolver resolver)
+                                                                        final String methodName)
     {
-        return factory.createMessage(BUNDLE_PATH, 239, methodName, component, resolver);
+        return factory.createMessage(BUNDLE_PATH, 239, methodName, component);
     }
 
-    public static Message noEntryPointFoundWithArgsUsingResolver(Object object, Object args, EntryPointResolver resolver)
+    public static Message noEntryPointFoundWithArgsUsingResolver(Object object,
+                                                                 Object args)
     {
-        return factory.createMessage(BUNDLE_PATH, 240, StringMessageUtils.toString(object), StringMessageUtils.toString(args),
-                resolver);
+        return factory.createMessage(BUNDLE_PATH, 240, StringMessageUtils.toString(object),
+            StringMessageUtils.toString(args));
     }
 
     public static Message noMatchingMethodsOnObjectReturningUsingResolver(Object object,
-                                                                          Class returnType,
-                                                                          EntryPointResolver resolver)
+                                                                          Class<?> returnType)
     {
-        return factory.createMessage(BUNDLE_PATH, 241, StringMessageUtils.toString(object), returnType.getClass().getName(),
-                resolver);
+        return factory.createMessage(BUNDLE_PATH, 241, StringMessageUtils.toString(object),
+            returnType.getClass().getName());
     }
 
     public static Message tooManyAcceptableMethodsOnObjectUsingResolverForTypes(Object object,
                                                                                 Object types,
-                                                                                EntryPointResolver resolver)
+                                                                                String methods)
     {
-        return factory.createMessage(BUNDLE_PATH, 242, StringMessageUtils.toString(object), StringMessageUtils.toString(types),
-                resolver);
+        return factory.createMessage(BUNDLE_PATH, 242, StringMessageUtils.toString(object),
+            StringMessageUtils.toString(types), methods);
     }
 
     public static Message tooManyMatchingMethodsOnObjectUsingResolverWhichReturn(Object object,
-                                                                                 Object returnType,
-                                                                                 EntryPointResolver resolver)
+                                                                                 Object returnType)
     {
         return factory.createMessage(BUNDLE_PATH, 243, StringMessageUtils.toString(returnType),
-                StringMessageUtils.toString(object), resolver);
+            StringMessageUtils.toString(object));
     }
 
-    public static Message objectDoesNotImplementInterface(Object object, Class interfaceClass)
+    public static Message objectDoesNotImplementInterface(Object object, Class<?> interfaceClass)
     {
         return factory.createMessage(BUNDLE_PATH, 244, StringMessageUtils.toString(object), interfaceClass);
     }
@@ -993,10 +1004,9 @@ public class CoreMessages extends MessageFactory
     }
 
     public static Message noMatchingMethodsOnObjectCalledUsingResolver(Object object,
-                                                                       String methodName,
-                                                                       EntryPointResolver resolver)
+                                                                       String methodName)
     {
-        return factory.createMessage(BUNDLE_PATH, 246, StringMessageUtils.toString(object), methodName, resolver);
+        return factory.createMessage(BUNDLE_PATH, 246, StringMessageUtils.toString(object), methodName);
     }
 
     public static Message noJtaTransactionAvailable(final Thread callingThread)
@@ -1023,7 +1033,7 @@ public class CoreMessages extends MessageFactory
     {
         return factory.createMessage(BUNDLE_PATH, 251, key);
     }
-
+    
     public static Message objectAlreadyExists(String key)
     {
         return factory.createMessage(BUNDLE_PATH, 252, key);
@@ -1036,8 +1046,8 @@ public class CoreMessages extends MessageFactory
 
     public static Message objectAlreadyRegistered(String name, Object origObject, Object newObject)
     {
-        return factory.createMessage(BUNDLE_PATH, 254, name, origObject + "." + origObject.getClass(), newObject + "."
-                + newObject.getClass());
+        return factory.createMessage(BUNDLE_PATH, 254, name, origObject + "." + origObject.getClass(),
+            newObject + "." + newObject.getClass());
     }
 
     public static Message transformerNotImplementDiscoverable(Transformer transformer)
@@ -1045,22 +1055,25 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 255, transformer);
     }
 
-    public static Message transformHasMultipleMatches(Class input,
-                                                      Class output,
+    public static Message transformHasMultipleMatches(Class<?> input,
+                                                      Class<?> output,
                                                       Transformer transformer1,
                                                       Transformer transformer2)
     {
-        return factory.createMessage(BUNDLE_PATH, 256, new Object[]{input, output,
+        return factory.createMessage(BUNDLE_PATH, 256, input, output,
                 transformer1.getName() + "(" + transformer1.getClass() + ")",
-                transformer2.getName() + "(" + transformer2.getClass() + ")"});
+                transformer2.getName() + "(" + transformer2.getClass() + ")");
     }
 
-    public static Message configurationBuilderSuccess(ConfigurationBuilder configurationBuilder, int numResources)
+    public static Message configurationBuilderSuccess(ConfigurationBuilder configurationBuilder,
+                                                      int numResources)
     {
-        return factory.createMessage(BUNDLE_PATH, 257, configurationBuilder.getClass().getName(), new Integer(numResources));
+        return factory.createMessage(BUNDLE_PATH, 257, configurationBuilder.getClass().getName(),
+            new Integer(numResources));
     }
 
-    public static Message configurationBuilderSuccess(ConfigurationBuilder configurationBuilder, String resources)
+    public static Message configurationBuilderSuccess(ConfigurationBuilder configurationBuilder,
+                                                      String resources)
     {
         return factory.createMessage(BUNDLE_PATH, 258, configurationBuilder.getClass().getName(), resources);
     }
@@ -1072,7 +1085,8 @@ public class CoreMessages extends MessageFactory
 
     public static Message configurationBuilderError(ConfigurationBuilder configurationBuilder)
     {
-        return factory.createMessage(BUNDLE_PATH, 260, StringMessageUtils.toString(configurationBuilder.getClass()));
+        return factory.createMessage(BUNDLE_PATH, 260,
+            StringMessageUtils.toString(configurationBuilder.getClass()));
     }
 
     public static Message nestedRetry()
@@ -1100,23 +1114,11 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 266, groupId);
     }
 
-    public static Message transformerInvalidReturnType(Class clazz, String transformerName)
+    public static Message transformerInvalidReturnType(Class<?> clazz, String transformerName)
     {
         return factory.createMessage(BUNDLE_PATH, 267, clazz, transformerName);
     }
 
-    /**
-     * 
-     * @deprecated Use more specific {@link #commitTxButNoResource} or
-     * {@link #rollbackTxButNoResource}
-     */
-    @Deprecated
-    public static Message noBindingResource()
-    {
-        return factory.createMessage(BUNDLE_PATH, 268);
-    }
-
-
     public static Message transactionFactoryIsMandatory(String action)
     {
         return factory.createMessage(BUNDLE_PATH, 269, action);
@@ -1142,12 +1144,12 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 273, what);
     }
 
-    public static Message stopPausedSedaServiceNonPeristentQueueMessageLoss(int num, Service service)
+    public static Message stopPausedSedaStageNonPeristentQueueMessageLoss(int num, String name)
     {
-        return factory.createMessage(BUNDLE_PATH, 274, num, service.getName());
+        return factory.createMessage(BUNDLE_PATH, 274, num, name);
     }
 
-    public static Message splitMessageNoEndpointMatch(List endpoints, Object messagePart)
+    public static Message splitMessageNoEndpointMatch(List<?> endpoints, Object messagePart)
     {
         return factory.createMessage(BUNDLE_PATH, 275, StringMessageUtils.toString(endpoints), messagePart);
     }
@@ -1171,7 +1173,7 @@ public class CoreMessages extends MessageFactory
     {
         return factory.createMessage(BUNDLE_PATH, 301, tx);
     }
-    
+
     public static Message cannotCopyStreamPayload(String streamType)
     {
         return factory.createMessage(BUNDLE_PATH, 302, streamType);
@@ -1187,4 +1189,157 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 304);
     }
 
+    public static Message lifecyclePhaseNotRecognised(String phase)
+    {
+        return factory.createMessage(BUNDLE_PATH, 305, phase);
+    }
+
+    public static Message notificationListenerSubscriptionAlreadyRegistered(ListenerSubscriptionPair listenerPair)
+    {
+        return factory.createMessage(BUNDLE_PATH, 306, listenerPair);
+    }
+
+    public static Message applicationShutdownNormally(String appName, Date date)
+    {
+        return factory.createMessage(BUNDLE_PATH, 307, appName, date);
+    }
+
+    public static Message applicationWasUpForDuration(long duration)
+    {
+        String formattedDuration = DateUtils.getFormattedDuration(duration);
+        return factory.createMessage(BUNDLE_PATH, 308, formattedDuration);
+    }
+
+    public static Message errorSchedulingMessageProcessorForAsyncInvocation(MessageProcessor processor)
+    {
+        return factory.createMessage(BUNDLE_PATH, 309, processor);
+    }
+
+    public static Message errorInvokingMessageProcessorAsynchronously(MessageProcessor processor)
+    {
+        return factory.createMessage(BUNDLE_PATH, 310, processor);
+    }
+
+    public static Message errorInvokingMessageProcessorWithinTransaction(MessageProcessor processor,
+                                                                         TransactionConfig transactionConfig)
+    {
+        return factory.createMessage(BUNDLE_PATH, 311, processor, transactionConfig);
+    }
+
+    private static String getEndpointDescription(InboundEndpoint endpoint)
+    {
+        String endpointString = endpoint.getName();
+        if (endpointString == null)
+        {
+            endpointString = endpoint.getEndpointURI().getUri().toString();
+        }
+        return endpointString;
+    }
+    
+    public static Message failedToStartInboundEndpoint(InboundEndpoint endpoint)
+    {
+        return factory.createMessage(BUNDLE_PATH, 312, getEndpointDescription(endpoint));
+    }
+
+    public static Message failedToStopInboundEndpoint(InboundEndpoint endpoint)
+    {
+        return factory.createMessage(BUNDLE_PATH, 313, getEndpointDescription(endpoint));
+    }
+
+    public static Message messageRejectedByFilter()
+    {
+        return factory.createMessage(BUNDLE_PATH, 314);
+    }
+    
+    public static Message interruptedWaitingForPaused(String name)
+    {
+        return factory.createMessage(BUNDLE_PATH, 315, name);
+    }
+
+    public static Message objectHasMoreThanOnePostConstructAnnotation(Class<?> clazz)
+    {
+        return factory.createMessage(BUNDLE_PATH, 316, clazz.getName());
+    }
+
+    public static Message objectHasMoreThanOnePreDestroyAnnotation(Class<?> clazz)
+    {
+        return factory.createMessage(BUNDLE_PATH, 317, clazz.getName());
+    }
+
+    public static Message lifecycleMethodNotVoidOrHasParams(Method method)
+    {
+        return factory.createMessage(BUNDLE_PATH, 318, method.getName());
+    }
+
+    public static Message lifecycleMethodCannotBeStatic(Method method)
+    {
+        return factory.createMessage(BUNDLE_PATH, 319, method.getName());
+    }
+
+    public static Message lifecycleMethodCannotThrowChecked(Method method)
+    {
+        return factory.createMessage(BUNDLE_PATH, 320, method.getName());
+    }
+
+    public static Message cannotRenameInboundScopeProperty(String fromKey, String toKey)
+    {
+        return factory.createMessage(BUNDLE_PATH, 321, fromKey, toKey);
+    }
+
+    public static Message failedToFindEntrypointForComponent(String message)
+    {
+        return factory.createMessage(BUNDLE_PATH, 322, message);
+    }
+
+    public static Message exchangePatternForEndpointNotSupported(MessageExchangePattern mep,
+        String direction, EndpointURI endpointURI)
+    {
+        return factory.createMessage(BUNDLE_PATH, 323, mep.name(), direction, endpointURI);
+    }
+
+    public static Message illegalMIMEType(String badMIMIEType)
+    {
+        return factory.createMessage(BUNDLE_PATH, 324, badMIMIEType);
+    }
+
+    public static Message unexpectedMIMEType(String badMIMIEType, String goodMIMEType)
+    {
+        return factory.createMessage(BUNDLE_PATH, 325, badMIMIEType, goodMIMEType);
+    }
+
+    public static Message dynamicEndpointURIsCannotBeUsedOnInbound()
+    {
+        return factory.createMessage(BUNDLE_PATH, 326);
+    }
+
+    public static Message dynamicEndpointsMustSpecifyAScheme()
+    {
+        return factory.createMessage(BUNDLE_PATH, 327);
+    }
+
+    public static Message asyncDoesNotSupportTransactions()
+    {
+        return factory.createMessage(BUNDLE_PATH, 328);
+    }
+    
+    public static Message methodWithNumParamsNotFoundOnObject(String method, int numArgments, Object object)
+    {
+        return factory.createMessage(BUNDLE_PATH, 329, method, numArgments,
+            StringMessageUtils.toString(object));
+    }
+    
+    public static Message expressionEnricherNotRegistered(String key)
+    {
+        return factory.createMessage(BUNDLE_PATH, 330, key);
+    }
+
+    public static Message authorizationDeniedOnEndpoint(EndpointURI endpointURI)
+    {
+        return factory.createMessage(BUNDLE_PATH, 331, endpointURI);
+    }
+
+    public static Message objectStoreNotFound(String name)
+    {
+        return factory.createMessage(BUNDLE_PATH, 332, name);
+    }
 }
