@@ -1,7 +1,7 @@
 /*
- * $Id: AbstractConfigBuilderTestCase.java 14826 2009-05-28 09:25:21Z rossmason $
+ * $Id: AbstractConfigBuilderTestCase.java 21906 2011-05-13 22:02:37Z tcarlson $
  * --------------------------------------------------------------------------------------
- * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
+ * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
@@ -10,17 +10,15 @@
 
 package org.mule.tck;
 
-import org.mule.DefaultExceptionStrategy;
 import org.mule.api.DefaultMuleException;
 import org.mule.api.MuleException;
+import org.mule.api.component.InterfaceBinding;
 import org.mule.api.component.JavaComponent;
 import org.mule.api.config.ThreadingProfile;
 import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
-import org.mule.api.endpoint.OutboundEndpoint;
-import org.mule.api.routing.InboundRouter;
-import org.mule.api.routing.InboundRouterCollection;
-import org.mule.api.routing.InterfaceBinding;
+import org.mule.api.exception.MessagingExceptionHandler;
+import org.mule.api.processor.MessageProcessor;
 import org.mule.api.routing.OutboundRouter;
 import org.mule.api.routing.OutboundRouterCollection;
 import org.mule.api.routing.filter.Filter;
@@ -35,19 +33,20 @@ import org.mule.interceptor.InterceptorStack;
 import org.mule.interceptor.LoggingInterceptor;
 import org.mule.interceptor.TimerInterceptor;
 import org.mule.model.seda.SedaService;
+import org.mule.routing.IdempotentMessageFilter;
+import org.mule.routing.MessageFilter;
 import org.mule.routing.filters.MessagePropertyFilter;
 import org.mule.routing.filters.PayloadTypeFilter;
 import org.mule.routing.filters.RegExFilter;
 import org.mule.routing.filters.logic.AndFilter;
-import org.mule.routing.inbound.IdempotentReceiver;
-import org.mule.routing.inbound.SelectiveConsumer;
 import org.mule.routing.outbound.FilteringOutboundRouter;
+import org.mule.service.ServiceCompositeMessageSource;
 import org.mule.tck.testmodels.mule.TestCatchAllStrategy;
 import org.mule.tck.testmodels.mule.TestCompressionTransformer;
-import org.mule.tck.testmodels.mule.TestConnector;
 import org.mule.tck.testmodels.mule.TestExceptionStrategy;
 import org.mule.tck.testmodels.mule.TestTransactionFactory;
 import org.mule.transformer.TransformerUtils;
+import org.mule.transformer.types.DataTypeFactory;
 import org.mule.transport.AbstractConnector;
 
 public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfigBuilderTestCase
@@ -57,7 +56,12 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         super(legacy);
     }
-
+    
+    @Override
+    protected boolean isGracefulShutdown()
+    {
+        return true;
+    }
 
     @Override
     public void testManagerConfig() throws Exception
@@ -72,17 +76,16 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         super.testConnectorConfig();
 
-        TestConnector c = (TestConnector) muleContext.getRegistry().lookupConnector("dummyConnector");
-        assertNotNull(c);
-        assertNotNull(c.getExceptionListener());
-        assertTrue(c.getExceptionListener() instanceof TestExceptionStrategy);
+        MessagingExceptionHandler es = muleContext.getRegistry().lookupModel("main").getExceptionListener();
+        assertNotNull(es);
+        assertTrue(es.getClass().getName(), es instanceof TestExceptionStrategy);
     }
 
     @Override
     public void testGlobalEndpointConfig() throws MuleException
     {
         super.testGlobalEndpointConfig();
-        ImmutableEndpoint endpoint = muleContext.getRegistry().lookupEndpointFactory().getInboundEndpoint("fruitBowlEndpoint");
+        ImmutableEndpoint endpoint = muleContext.getEndpointFactory().getInboundEndpoint("fruitBowlEndpoint");
         assertNotNull(endpoint);
         assertEquals(endpoint.getEndpointURI().getAddress(), "fruitBowlPublishQ");
 
@@ -96,8 +99,8 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         super.testEndpointConfig();
 
-        // test that endpoints have been resolved on endpoints
-        ImmutableEndpoint endpoint = muleContext.getRegistry().lookupEndpointFactory().getInboundEndpoint("waterMelonEndpoint");
+        // test that targets have been resolved on targets
+        ImmutableEndpoint endpoint = muleContext.getEndpointFactory().getInboundEndpoint("waterMelonEndpoint");
         assertNotNull(endpoint);
         assertEquals("UTF-8-TEST", endpoint.getEncoding());
         assertEquals("test.queue", endpoint.getEndpointURI().getAddress());
@@ -110,7 +113,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         Service service = muleContext.getRegistry().lookupService("appleComponent");
         assertNotNull(service.getExceptionListener());
-        assertTrue(DefaultExceptionStrategy.class.isAssignableFrom(service.getExceptionListener().getClass()));
+        assertTrue(service.getExceptionListener() instanceof MessagingExceptionHandler);
     }
 
     @Override
@@ -121,7 +124,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
         Transformer t = muleContext.getRegistry().lookupTransformer("TestCompressionTransformer");
         assertNotNull(t);
         assertTrue(t instanceof TestCompressionTransformer);
-        assertEquals(t.getReturnClass(), java.lang.String.class);
+        assertEquals(t.getReturnDataType(), DataTypeFactory.STRING);
         assertNotNull(((TestCompressionTransformer) t).getContainerProperty());
     }
 
@@ -137,16 +140,18 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         // test outbound message router
         Service service = muleContext.getRegistry().lookupService("appleComponent");
-        assertNotNull(service.getOutboundRouter());
-        OutboundRouterCollection router = service.getOutboundRouter();
+        assertNotNull(service.getOutboundMessageProcessor());
+        OutboundRouterCollection router = (OutboundRouterCollection) service.getOutboundMessageProcessor();
         assertNotNull(router.getCatchAllStrategy());
-        assertEquals(2, router.getRouters().size());
+        assertEquals(2, router.getRoutes().size());
         // check first Router
-        OutboundRouter route1 = (OutboundRouter) router.getRouters().get(0);
+        OutboundRouter route1 = (OutboundRouter) router.getRoutes().get(0);
         assertTrue(route1 instanceof FilteringOutboundRouter);
-        assertNotNull(((FilteringOutboundRouter) route1).getTransformers());
-        assertTrue(TransformerUtils.firstOrNull(((FilteringOutboundRouter) route1).getTransformers())
-                instanceof TestCompressionTransformer);
+        assertEquals(1, route1.getRoutes().size());
+        ImmutableEndpoint ep = (ImmutableEndpoint) route1.getRoutes().get(0);
+        
+        assertNotNull(ep.getTransformers());
+        assertTrue(TransformerUtils.firstOrNull(ep.getTransformers()) instanceof TestCompressionTransformer);
 
         Filter filter = ((FilteringOutboundRouter) route1).getFilter();
         assertNotNull(filter);
@@ -154,15 +159,15 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
         assertEquals(String.class, ((PayloadTypeFilter) filter).getExpectedType());
 
         // check second Router
-        OutboundRouter route2 = (OutboundRouter) router.getRouters().get(1);
+        OutboundRouter route2 = (OutboundRouter) router.getRoutes().get(1);
         assertTrue(route2 instanceof FilteringOutboundRouter);
 
         Filter filter2 = ((FilteringOutboundRouter) route2).getFilter();
         assertNotNull(filter2);
         assertTrue(filter2 instanceof AndFilter);
         assertEquals(2,  ((AndFilter) filter2).getFilters().size());
-        Filter left = (Filter) ((AndFilter) filter2).getFilters().get(0);
-        Filter right = (Filter) ((AndFilter) filter2).getFilters().get(1);
+        Filter left = ((AndFilter) filter2).getFilters().get(0);
+        Filter right = ((AndFilter) filter2).getFilters().get(1);
         assertNotNull(left);
         assertTrue(left instanceof RegExFilter);
         assertEquals("the quick brown (.*)", ((RegExFilter) left).getPattern());
@@ -177,13 +182,13 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     public void testInboundRouterConfig2()
     {
         Service service = muleContext.getRegistry().lookupService("appleComponent");
-        assertNotNull(service.getInboundRouter());
-        InboundRouterCollection messageRouter = service.getInboundRouter();
+        assertNotNull(service.getMessageSource());
+        ServiceCompositeMessageSource messageRouter = (ServiceCompositeMessageSource) service.getMessageSource();
         assertNotNull(messageRouter.getCatchAllStrategy());
-        assertEquals(2, messageRouter.getRouters().size());
-        InboundRouter router = (InboundRouter) messageRouter.getRouters().get(0);
-        assertTrue(router instanceof SelectiveConsumer);
-        SelectiveConsumer sc = (SelectiveConsumer) router;
+        assertEquals(2, messageRouter.getMessageProcessors().size());
+        MessageProcessor router = messageRouter.getMessageProcessors().get(0);
+        assertTrue(router instanceof MessageFilter);
+        MessageFilter sc = (MessageFilter) router;
 
         assertNotNull(sc.getFilter());
         Filter filter = sc.getFilter();
@@ -191,8 +196,8 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
         assertTrue(filter instanceof PayloadTypeFilter);
         assertEquals(String.class, ((PayloadTypeFilter) filter).getExpectedType());
 
-        InboundRouter router2 = (InboundRouter) messageRouter.getRouters().get(1);
-        assertTrue(router2 instanceof IdempotentReceiver);
+        MessageProcessor router2 = messageRouter.getMessageProcessors().get(1);
+        assertTrue(router2 instanceof IdempotentMessageFilter);
     }
 
     public void testThreadingConfig() throws DefaultMuleException
@@ -260,7 +265,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     public void testPoolingConfig()
     {
 //        //TODO RM* test config
-//        PoolingProfile pp = RegistryContext.getConfiguration().getPoolingProfile();
+//        PoolingProfile pp = muleContext.getConfiguration().getPoolingProfile();
 //        assertEquals(10, pp.getMaxActive());
 //        assertEquals(5, pp.getMaxIdle());
 //        assertEquals(10001, pp.getMaxWait());
@@ -283,7 +288,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
 //        // test config
 //        //TODO RM*
-//        QueueProfile qp = RegistryContext.getConfiguration().getQueueProfile();
+//        QueueProfile qp = muleContext.getConfiguration().getQueueProfile();
 //        assertEquals(100, qp.getMaxOutstandingMessages());
 //        assertTrue(qp.isPersistent());
 
@@ -291,7 +296,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
         Service service = muleContext.getRegistry().lookupService("appleComponent2");
         QueueProfile qp = ((SedaService)service).getQueueProfile();
         assertEquals(102, qp.getMaxOutstandingMessages());
-        assertTrue(qp.isPersistent());
+        //assertTrue(qp.isPersistent());
 
         // test override
 //        descriptor = (MuleDescriptor)muleContext.getModel().getDescriptor("appleComponent2");
@@ -304,7 +309,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         // test transaction config
         Service service = muleContext.getRegistry().lookupService("appleComponent2");
-        InboundEndpoint inEndpoint = service.getInboundRouter().getEndpoint(
+        InboundEndpoint inEndpoint = ((ServiceCompositeMessageSource) service.getMessageSource()).getEndpoint(
                 "transactedInboundEndpoint");
         assertNotNull(inEndpoint);
         assertNotNull(inEndpoint.getProperties());
@@ -315,16 +320,16 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     {
         // test transaction config
         Service apple = muleContext.getRegistry().lookupService("appleComponent2");
-        InboundEndpoint inEndpoint = apple.getInboundRouter().getEndpoint("transactedInboundEndpoint");
+        InboundEndpoint inEndpoint = ((ServiceCompositeMessageSource) apple.getMessageSource()).getEndpoint("transactedInboundEndpoint");
         assertNotNull(inEndpoint);
-        assertEquals(1, apple.getOutboundRouter().getRouters().size());
+        assertEquals(1, ((OutboundRouterCollection) apple.getOutboundMessageProcessor()).getRoutes().size());
         assertNotNull(inEndpoint.getTransactionConfig());
         assertEquals(TransactionConfig.ACTION_ALWAYS_BEGIN, inEndpoint.getTransactionConfig().getAction());
         assertTrue(inEndpoint.getTransactionConfig().getFactory() instanceof TestTransactionFactory);
         assertNull(inEndpoint.getTransactionConfig().getConstraint());
 
-        OutboundRouter outRouter = (OutboundRouter) apple.getOutboundRouter().getRouters().get(0);
-        OutboundEndpoint outEndpoint = (OutboundEndpoint) outRouter.getEndpoints().get(0);
+        OutboundRouter outRouter = (OutboundRouter) ((OutboundRouterCollection)apple.getOutboundMessageProcessor()).getRoutes().get(0);
+        MessageProcessor outEndpoint = outRouter.getRoutes().get(0);
         assertNotNull(outEndpoint);
     }
 
@@ -342,7 +347,7 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
         Service orange = muleContext.getRegistry().lookupService("orangeComponent");
         assertNotNull(orange);
         assertTrue(orange.getComponent() instanceof JavaComponent);
-        InterfaceBinding r = (InterfaceBinding) ((JavaComponent) orange.getComponent()).getBindingCollection().getRouters().get(0);
+        InterfaceBinding r = ((JavaComponent) orange.getComponent()).getInterfaceBindings().get(0);
         assertNotNull(r);
 
         //TODO Grab an instance of the service object itself and test that the proxy has been injected
@@ -350,7 +355,9 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     
     public void testMuleConfiguration()
     {
-        assertTrue(muleContext.getConfiguration().isDefaultSynchronousEndpoints());
+        assertEquals(10,muleContext.getConfiguration().getDefaultResponseTimeout());
+        assertEquals(20,muleContext.getConfiguration().getDefaultTransactionTimeout());
+        assertEquals(30,muleContext.getConfiguration().getShutdownTimeout());
     }
 
     public void testGlobalInterceptorStack()
@@ -367,12 +374,10 @@ public abstract class AbstractConfigBuilderTestCase extends AbstractScriptConfig
     public void testInterceptors()
     {
         Service service = muleContext.getRegistry().lookupService("orangeComponent");
-        InterceptorStack globalInterceptorStack = (InterceptorStack) muleContext.getRegistry().lookupObject(
-            "testInterceptorStack");
         AbstractComponent component = (AbstractComponent) service.getComponent();
         assertEquals(3, component.getInterceptors().size());
         assertEquals(LoggingInterceptor.class, component.getInterceptors().get(0).getClass());
-        assertEquals(globalInterceptorStack, component.getInterceptors().get(1));
+        assertEquals(InterceptorStack.class, component.getInterceptors().get(1).getClass());
         assertEquals(TimerInterceptor.class, component.getInterceptors().get(2).getClass());
     }
     
